-- -----------------------------------------------------
-- Database QuizFaber x SQL Server , db version : 2
-- -----------------------------------------------------
-- Project : QuizFaber
-- Licence : MIT
-- Author  : Luca Galli
-- Email   : info@quizfaber.com
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Table QuizState
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizState' AND XTYPE='U')
CREATE TABLE QuizState (
  [Code] INT NOT NULL,
  [Description] VARCHAR(30) NULL,
  PRIMARY KEY ([Code]))

INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 0 AS Code,'Draft' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=0)
INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 1 AS Code,'Completed' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=1)
INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 2 AS Code,'Candidate' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=2)
INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 10 AS Code,'Published' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=10)
INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 98 AS Code,'Archived' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=98)
INSERT INTO QuizState (Code,Description) SELECT * FROM (SELECT 99 AS Code,'Deleted' AS Description) AS tmp  WHERE NOT EXISTS (SELECT * FROM QuizState WHERE Code=99)

-- -----------------------------------------------------
-- Table Quizzes
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Quizzes' AND XTYPE='U')
CREATE TABLE Quizzes (
  QZ_ID INT NOT NULL IDENTITY (1,1),
  quizname VARCHAR(255) NOT NULL,
  Title VARCHAR(1024) NOT NULL,
  IntroText VARCHAR(MAX) NULL,
  EpiText VARCHAR(MAX) NULL,
  NumQuestions INT NOT NULL,
  Author VARCHAR(255) NULL,
  Argument VARCHAR(255) NULL,
  Season VARCHAR(255) NULL,
  [State] INT NOT NULL DEFAULT 0,
  Link VARCHAR(255) NULL,
  Properties VARCHAR(MAX) NULL,
  DateCreated DATETIME NULL,
  DateModified DATETIME NULL,
  PRIMARY KEY (QZ_ID),
  CONSTRAINT FK_QuizState
    FOREIGN KEY (State)
    REFERENCES QuizState (Code))


-- -----------------------------------------------------
-- Table PersonRole
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='PersonRole' AND XTYPE='U')
CREATE TABLE PersonRole (
  ID INT NOT NULL,
  RoleName VARCHAR(80) NOT NULL,
  RoleDescription VARCHAR(500) NULL,
  IsEnabled BIT NOT NULL,
  PRIMARY KEY (ID))


-- -----------------------------------------------------
-- Table Person
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Person' AND XTYPE='U')
CREATE TABLE Person (
  ID INT NOT NULL IDENTITY (1,1),
  PersonName VARCHAR(255) NOT NULL,
  UserIdentity VARCHAR(255) NOT NULL,
  UserPassword VARCHAR(255) NOT NULL,
  UserRole INT NOT NULL,
  Info VARCHAR(MAX) NULL,
  IsEnabled BIT NOT NULL,
  [Source] VARCHAR(1) NULL,
  DateCreated DATETIME NULL,
  DateModified DATETIME NULL,
  DateLastAccess DATETIME NULL,
  PRIMARY KEY (ID),
  CONSTRAINT indexUserIdentity UNIQUE (UserIdentity),
  CONSTRAINT UserRole_FK
    FOREIGN KEY(UserRole) 
	REFERENCES PersonRole(ID))

-- -----------------------------------------------------
-- Table Categories
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Categories' AND XTYPE='U')
CREATE TABLE Categories (
  QZ_ID INT NOT NULL,
  CategoryName VARCHAR(80) NOT NULL,
  Description VARCHAR(MAX) NULL,
  MaxQuestForQuiz INT NULL,
  IsRandom BIT NULL,
  PRIMARY KEY (CategoryName, QZ_ID),
  CONSTRAINT FK_CategoryQuiz
    FOREIGN KEY (QZ_ID)
    REFERENCES Quizzes (QZ_ID)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table Questions
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Questions' AND XTYPE='U')
CREATE TABLE Questions (
  QZ_ID INT NOT NULL,
  Num INT NOT NULL,
  CategoryName VARCHAR(80) NOT NULL,
  TextQuestion VARCHAR(MAX) NOT NULL,
  QuestionName VARCHAR(256) NULL,
  Type INT NOT NULL,
  Weight FLOAT NOT NULL,
  Include BIT NOT NULL,
  TextFormat INT NOT NULL,
  SortAnswers BIT NOT NULL,
  TextAbove VARCHAR(MAX) NULL,
  TextBelow VARCHAR(MAX) NULL,
  Remark VARCHAR(MAX) NULL,
  PutSeparator BIT NULL,
  Timeout INT NULL,
  Html VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, Num),  
  CONSTRAINT Quest_FK
    FOREIGN KEY (QZ_ID)
    REFERENCES Quizzes (QZ_ID)
    ON DELETE NO ACTION 
    ON UPDATE NO ACTION,
  CONSTRAINT Category_FK
    FOREIGN KEY (CategoryName , QZ_ID)
    REFERENCES Categories (CategoryName , QZ_ID)
    ON DELETE NO ACTION 
    ON UPDATE NO ACTION)



-- -----------------------------------------------------
-- Table ChoiceAnswers
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='ChoiceAnswers' AND XTYPE='U')
CREATE TABLE ChoiceAnswers (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  TypeOfAns INT NOT NULL,
  SingleAns BIT NOT NULL,
  PRIMARY KEY (QZ_ID, NumQst),
  CONSTRAINT ChoiceAns_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table ChoiceAnswerItems
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='ChoiceAnswerItems' AND XTYPE='U')
CREATE TABLE ChoiceAnswerItems (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  NumAns INT NOT NULL,
  TextFormat INT NOT NULL,
  Ans VARCHAR(MAX) NOT NULL,
  RightAns BIT NOT NULL,
  Hint VARCHAR(MAX) NULL,
  Rem VARCHAR(MAX) NULL,
  PointsIn INT NULL,
  PointsOut INT NULL,
  Html VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, NumQst, NumAns),
  CONSTRAINT ChoiceItems_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES ChoiceAnswers (QZ_ID , NumQst)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table BooleanAnswerItems
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='BooleanAnswerItems' AND XTYPE='U')
CREATE TABLE BooleanAnswerItems (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  NumAns INT NOT NULL,
  Sentence VARCHAR(MAX) NOT NULL,
  TrueAns BIT NOT NULL,
  TextFormat INT NOT NULL,
  Html VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, NumQst, NumAns),
  CONSTRAINT BoolAns_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table FillGapAnswers
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='FillGapAnswers' AND XTYPE='U')
CREATE TABLE FillGapAnswers (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  Phrase VARCHAR(MAX) NOT NULL,
  Type INT NOT NULL,
  TextFormat INT NOT NULL,
  Html VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, NumQst),
  CONSTRAINT FillGap_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table MatchingAnswers
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='MatchingAnswers' AND XTYPE='U')
CREATE TABLE MatchingAnswers (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  Type INT NOT NULL,
  PRIMARY KEY (QZ_ID, NumQst),
  CONSTRAINT Match_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table PairNames
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='PairNames' AND XTYPE='U')
CREATE TABLE PairNames (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  NumAns INT NOT NULL,
  LeftItem VARCHAR(MAX) NOT NULL,
  RightItem VARCHAR(MAX) NOT NULL,
  TextFormat INT NOT NULL,
  Html VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, NumQst, NumAns),
  CONSTRAINT PairNames_FK
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES MatchingAnswers (QZ_ID , NumQst)
    ON DELETE CASCADE
    ON UPDATE CASCADE)


	
-- -----------------------------------------------------
-- Table CustomQuestionTypes
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='CustomQuestionTypes' AND XTYPE='U')
CREATE TABLE CustomQuestionTypes (
  QZ_ID INT NOT NULL,
  CustomName VARCHAR(255) NOT NULL,
  Description VARCHAR(MAX) NULL,
  Version INT NULL,
  Subversion INT NULL,
  IconData VARCHAR(MAX) NULL,
  IncludeConfirmButton BIT NULL,
  ValuateRightWrong BIT NULL,
  MaxScore INT NULL,
  MinScore INT NULL,
  JscriptCode VARCHAR(MAX) NULL,
  HtmlCode VARCHAR(MAX) NULL,
  PRIMARY KEY (QZ_ID, CustomName),
  CONSTRAINT FK_CustomQuestionType_Quiz
    FOREIGN KEY (QZ_ID)
    REFERENCES Quizzes (QZ_ID)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table CustomParameters
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='CustomParameters' AND XTYPE='U')
CREATE TABLE CustomParameters (
  QZ_ID INT NOT NULL,
  CustomName VARCHAR(255) NOT NULL,
  ParamName VARCHAR(255) NOT NULL,
  IsEncrypt BIT NOT NULL,
  Type INT NOT NULL,
  DefValue VARCHAR(255) NULL,
  PRIMARY KEY (QZ_ID, CustomName, ParamName),
  CONSTRAINT FK_Params
    FOREIGN KEY (QZ_ID , CustomName)
    REFERENCES CustomQuestionTypes (QZ_ID , CustomName)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table CustomHeadTags
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='CustomHeadTags' AND XTYPE='U')
CREATE TABLE CustomHeadTags (
  QZ_ID INT NOT NULL,
  CustomName VARCHAR(255) NOT NULL,
  FileName VARCHAR(255) NOT NULL,
  Content VARCHAR(MAX) NOT NULL,
  ContentType INT NOT NULL,
  PRIMARY KEY (FileName, CustomName, QZ_ID),
  CONSTRAINT FK_CustomHeadTags
    FOREIGN KEY (QZ_ID , CustomName)
    REFERENCES CustomQuestionTypes (QZ_ID , CustomName)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table CustomAnswers
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='CustomAnswers' AND XTYPE='U')
CREATE TABLE CustomAnswers (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  CustomName VARCHAR(255) NOT NULL,
  ParamName VARCHAR(255) NOT NULL,
  ParamValue VARCHAR(255) NOT NULL,
  PRIMARY KEY (QZ_ID, NumQst, CustomName, ParamName),
  CONSTRAINT FK_CustomAns_To_Question
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT FK_CustomAns_To_CustomParams
    FOREIGN KEY (QZ_ID , CustomName , ParamName)
    REFERENCES CustomParameters (QZ_ID , CustomName , ParamName)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table Slides
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Slides' AND XTYPE='U')
CREATE TABLE Slides (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  SlideName VARCHAR(80) NOT NULL,
  Content VARCHAR(MAX) NOT NULL,
  TextFormat INT NOT NULL,
  BeforeQst BIT NOT NULL,
  IsExternal BIT NOT NULL,
  HtmlFileName VARCHAR(255) NULL,
  SpeechFileName VARCHAR(255) NULL,
  Timeout INT NULL,
  PRIMARY KEY (QZ_ID, NumQst, SlideName),
  CONSTRAINT FK_Slide_To_Question
    FOREIGN KEY (QZ_ID , NumQst)
    REFERENCES Questions (QZ_ID , Num)
    ON DELETE CASCADE
    ON UPDATE CASCADE)



-- -----------------------------------------------------
-- Table SlideDocs
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='SlideDocs' AND XTYPE='U')
CREATE TABLE SlideDocs (
  QZ_ID INT NOT NULL,
  NumQst INT NOT NULL,
  SlideName VARCHAR(80) NOT NULL,
  DocFileName VARCHAR(255) NOT NULL,
  LinkName VARCHAR(500) NOT NULL,
  PRIMARY KEY (DocFileName, QZ_ID, NumQst, SlideName),
  CONSTRAINT FK_Doc_To_Slide
    FOREIGN KEY (QZ_ID , NumQst , SlideName)
    REFERENCES Slides (QZ_ID , NumQst , SlideName)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)


-- -----------------------------------------------------
-- Table QuizResult
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizResult' AND XTYPE='U')
CREATE TABLE QuizResult (
  ID INT NOT NULL IDENTITY (1,1),
  QuizName VARCHAR(255) NOT NULL,
  QuizTitle VARCHAR(1024) NOT NULL,
  QuizID INT NULL,
  UserName VARCHAR(255) NOT NULL,
  UserLogin VARCHAR(255) NOT NULL,
  DateCompleted DATETIME NOT NULL,
  DateReceived DATETIME NOT NULL,
  QuestsNum INT NOT NULL,
  HighestMark INT NOT NULL,
  LowestMark INT NOT NULL DEFAULT 0,
  RoundMark FLOAT(12) NOT NULL DEFAULT 1,
  FinalMark FLOAT(12) NOT NULL,
  ReviewMark FLOAT(12) NULL,
  ReviewDate DATETIME NULL,
  FinalPoints FLOAT(12) NULL,
  ReviewPoints FLOAT(12) NULL,
  TotalTime INT NOT NULL,
  ElapsedTime INT NOT NULL,
  RightQuestsNum INT NOT NULL,
  WrongQuestsNum INT NOT NULL,
  NotAnsweredQuestsNum INT NULL,
  NotValuatedQuestsNum INT NULL,
  NumOfRetake INT NOT NULL,
  IsDuplicated BIT NULL,
  PRIMARY KEY (ID))


-- -----------------------------------------------------
-- Table QuizResultReport
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizResultReport' AND XTYPE='U')
CREATE TABLE QuizResultReport (
  ID INT NOT NULL,
  Origin VARCHAR(MAX) NULL,  
  Report VARCHAR(MAX) NULL,  
  Charset VARCHAR(255) NULL,
  [Language] VARCHAR(10) NULL,
  PRIMARY KEY (ID),
  CONSTRAINT FK_Report_QuizResult
    FOREIGN KEY (ID)
    REFERENCES QuizResult (ID)
    ON DELETE CASCADE
    ON UPDATE CASCADE)


-- -----------------------------------------------------
-- Table QuizResultQuestion
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizResultQuestion' AND XTYPE='U')
CREATE TABLE QuizResultQuestion (
  ID INT NOT NULL IDENTITY (1,1),
  IdQuizResult INT NOT NULL,
  QuestNum INT NOT NULL,
  QuestType INT NOT NULL,
  [Weight] FLOAT(12) NOT NULL,
  ShortTextQuestion VARCHAR(500) NULL,
  Valid INT NOT NULL,
  Score INT NOT NULL,
  MaxScore INT NOT NULL,
  MinScore INT NOT NULL,
  Points FLOAT(12) NULL,
  Feedback VARCHAR(MAX) NULL,
  IsCancelled BIT NULL,
  PRIMARY KEY (ID),
  CONSTRAINT FK_ResultQuestion_To_Result
    FOREIGN KEY (IdQuizResult)
    REFERENCES QuizResult(ID)
    ON DELETE CASCADE
    ON UPDATE CASCADE)


-- -----------------------------------------------------
-- Table QuizResultAnswer
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizResultAnswer' AND XTYPE='U')
CREATE TABLE QuizResultAnswer (
  IdResultQuestion INT NOT NULL,
  AnswerNum INT NOT NULL,
  Choice VARCHAR(500) NOT NULL,
  Valuation VARCHAR(500) NOT NULL,
  IsGuess BIT NOT NULL,
  Score INT NULL,
  AdditionalText VARCHAR(MAX) NULL,
  ShortTextAnswer VARCHAR(1000) NULL,
  ShortTextRemark VARCHAR(1000) NULL,
  PRIMARY KEY (IdResultQuestion,AnswerNum),
  CONSTRAINT FK_ResultAnswer_To_ResultQuestion
    FOREIGN KEY (IdResultQuestion)
    REFERENCES QuizResultQuestion(ID)
    ON DELETE CASCADE
    ON UPDATE CASCADE)


-- -----------------------------------------------------
-- Table QuizSession
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='QuizSession' AND XTYPE='U')
CREATE TABLE QuizSession (
  PersonID INT NOT NULL,
  SessionID INT NOT NULL IDENTITY (1,1),
  DateCreated DATETIME NOT NULL,
  IpLogin VARCHAR(46) NULL,
  SessionData VARCHAR(MAX) NULL,
  DateLastUpdate DATETIME NULL,
  QuizID INT NULL,
  IpLogout VARCHAR(46) NULL,
  UserAgent VARCHAR(255) NULL,
  IsRecoverable BIT NULL,
  PRIMARY KEY (SessionID),
  CONSTRAINT FK_QuizSessionPerson
    FOREIGN KEY (PersonID)
    REFERENCES Person (ID),
  CONSTRAINT FK_QuizSessionQuizResult
    FOREIGN KEY (QuizID)
    REFERENCES QuizResult (ID))

-- -----------------------------------------------------
-- Table Settings
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='Settings' AND XTYPE='U')
CREATE TABLE Settings (
  DbVersion INT NOT NULL,
  DateCreated DATETIME NULL,
  DateModified DATETIME NULL,
  ServerName VARCHAR(50) NULL,
  ServerDescription VARCHAR(50) NULL,
  ServerVersion VARCHAR(50) NULL,
  Environment VARCHAR(50) NULL,
  PortalBaseUrl VARCHAR(255) NULL,
  PhpMyAdminUrl VARCHAR(255) NULL,
  OwnerUrl VARCHAR(255) NULL,
  FooterText VARCHAR(255) NULL)

-- -----------------------------------------------------
-- Table WebLog
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='WebLog' AND XTYPE='U')
CREATE TABLE WebLog (
  ID INT NOT NULL IDENTITY (1,1),
  UserIdentity VARCHAR(255) NULL,
  SeverityLevel INT NULL,
  DateCreated DATETIME NULL,
  [Message] VARCHAR(MAX) NULL,
  PRIMARY KEY (ID))

-- -----------------------------------------------------
-- Table WebSeverityLevel
-- -----------------------------------------------------
IF NOT EXISTS (SELECT * FROM SYSOBJECTS WHERE NAME='WebSeverityLevel' AND XTYPE='U')
CREATE TABLE WebSeverityLevel (
  [Level] INT NOT NULL,
  [Description] VARCHAR(20) NULL)

DELETE FROM WebSeverityLevel;
INSERT INTO WebSeverityLevel (Level,Description) VALUES (0,'Debug');
INSERT INTO WebSeverityLevel (Level,Description) VALUES (1,'Info');
INSERT INTO WebSeverityLevel (Level,Description) VALUES (2,'Warning');
INSERT INTO WebSeverityLevel (Level,Description) VALUES (3,'Error');

INSERT INTO Settings (DbVersion,DateCreated,DateModified,ServerName,ServerDescription,ServerVersion,Environment,PortalBaseUrl,PhpMyAdminUrl,OwnerUrl,FooterText) SELECT 2,GETDATE(),GETDATE(),'Node.js server', 'Application for manage quizzes.','4.1.0','DEV','http://localhost:3313/',NULL,'https://www.quizfaber.com','QuizFaber' WHERE NOT EXISTS (SELECT * FROM Settings);

INSERT INTO PersonRole (ID,RoleName,RoleDescription,IsEnabled) SELECT * FROM ( SELECT 1 AS ID,'admin' AS RoleName,'administrator role' AS RoleDescription,1 AS IsEnabled) AS tmp WHERE NOT EXISTS (SELECT RoleName FROM PersonRole WHERE RoleName = 'admin');
INSERT INTO PersonRole (ID,RoleName,RoleDescription,IsEnabled) SELECT * FROM ( SELECT 2 AS ID,'user' AS RoleName,'user role' AS RoleDescription,1 AS IsEnabled) AS tmp WHERE NOT EXISTS (SELECT RoleName FROM PersonRole WHERE RoleName = 'user');

-- password : admin
INSERT INTO Person (PersonName,UserIdentity,UserPassword,UserRole,IsEnabled) SELECT * FROM (SELECT 'Administrator' AS PersonName,'admin' AS UserIdentity,'21232f297a57a5a743894a0e4a801fc3' AS UserPassword,1 AS UserRole,1 AS IsEnabled) AS tmp WHERE NOT EXISTS (SELECT UserIdentity FROM Person WHERE UserIdentity = 'admin')
-- password : anonymous
INSERT INTO Person (PersonName,UserIdentity,UserPassword,UserRole,IsEnabled) SELECT * FROM (SELECT 'Anonymous' AS PersonName, 'anonymous@anonymous.nowhere' AS UserIdentity,'294de3557d9d00b3d2d8a1e6aab028cf' AS UserPassword,2 AS UserRole,1 AS IsEnabled) AS tmp WHERE NOT EXISTS (SELECT UserIdentity FROM Person WHERE UserIdentity = 'anonymous@anonymous.nowhere')
